package
Version:
v1.1.1
Opens a new window with list of versions in this module.
Published: Nov 6, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Icon is kept for backward compatibility but should not be used directly
Use the icon passed to Run() instead
func Setup(icon []byte, showFunc func(), hideFunc func(), quitFunc func())
Setup is a no-op on non-darwin/non-windows platforms
Source Files
¶
Click to show internal directories.
Click to hide internal directories.